#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************

########################################################
#
# Script : CoreAutomationPrep_packages.sh [checkPreReqXvfbFlag(TRUE|FALSE)] [checkPreReqDMlibsFlag(TRUE|FALSE)]
# Purpose :
# - Ensure pre-required packages are installed
#
########################################################

scriptName=$0

# check the arguments
checkPreReqXvfbFlag=$1
checkPreReqDMlibsFlag=$2
if [ "X"$checkPreReqXvfbFlag"X" == "XX" ] || [ "X"$checkPreReqDMlibsFlag"X" == "XX" ]; then
  echo "$!checkPreReqXvfbFlag [$checkPreReqXvfbFlag] or $!checkPreReqDMlibsFlag [$checkPreReqDMlibsFlag] not set!"
  exit 1
fi

################
##  FUNCTIONS  #
################

# will check the package is installed
checkRHPackageInstalled()
{
  package=$1
  echo "---checking ${package} installed---"
  rpm -q ${package}
  if [ $? != 0 ]
  then
    echo "${package} package not installed"
    rhPackageInstalled="FALSE"
  else
    echo "${package} package is installed."
    rhPackageInstalled="TRUE"
  fi
  
}


# will check command in PATH using which
checkCommandInPath()
{
  command=$1
  echo "---checking ${command} in PATH---"
  which ${command}
  if [ $? != 0 ]
  then
    echo "${command} command not in PATH"
    rhCommandInPath="FALSE"
  else
    echo "${command} command in PATH."
    rhCommandInPath="TRUE"
  fi
  
}


## usage checkLibFileExists tempFile
checkLibFileExists()
{
  tempFile=$1
  echo "---checking lib ${tempFile} exists---"
  if [ -f $tempFile ]; then
    echo "lib file [$tempFile] exists"
    rhLibFileExists="TRUE"
  else
    echo "lib file [$tempFile] does not exists"
    rhLibFileExists="FALSE"
  fi
}


###########
##  MAIN  #
###########

####################################
# may need to check OS 
bRH6flag=FALSE
bRH7flag=FALSE

RHversion=`cat /etc/redhat-release`
echo "Current Red Hat Release $RHversion"

echo $RHversion | grep "Maipo"
if [ $? -eq 0 ]; then
  echo "OS is Red Hat 7"
  bRH7flag=TRUE
fi
echo $RHversion | grep "Santiago"
if [ $? -eq 0 ]; then
  echo "OS is Red Hat 6"
  bRH6flag=TRUE
fi

##if [ "TRUE" == $bRH6flag ] || [ "TRUE" == $bRH7flag ]; then
##  echo "supported OS"
##else
##  echo "ERROR: not a supported OS"
##  exit 1
##fi

####################################
# may need to check for RH packages 
packagesMissing=FALSE

########################################
# Check RH preReq packages are installed
echo "--- check RH preReq packages are installed ---"

# -- check expect package for SSH is installed and in the PATH
## ===========================================================
package=expect
checkRHPackageInstalled ${package}
if [ "FALSE" == $rhPackageInstalled ]; then 
  packagesMissing="TRUE"
fi
checkCommandInPath ${package}
if [ "FALSE" == $rhCommandInPath ]; then 
  packagesMissing="TRUE"
fi


# -- check Xvfb package for RM & DM pictures is installed and in the PATH
## ======================================================================
if [ "TRUE" == $checkPreReqXvfbFlag ]; then 
  package=xorg-x11-server-Xvfb
  checkRHPackageInstalled ${package}
  if [ "FALSE" == $rhPackageInstalled ]; then 
    packagesMissing="TRUE"
  fi
  packageCommand=Xvfb
  checkCommandInPath ${packageCommand}
  if [ "FALSE" == $rhCommandInPath ]; then 
    packagesMissing="TRUE"
  fi
fi

# -- check DM libraries present
# -- Note: checking for preReqs packages for DM server and desktop products
## ========================================================================
if [ "TRUE" == $checkPreReqDMlibsFlag ]; then
  
  # -- (RH6 and RH7) check 32 bit libXdmcp.so.6 package for DM 
  ## =======================================================
  package=libXdmcp.i686
  checkRHPackageInstalled ${package}
  if [ "FALSE" == $rhPackageInstalled ]; then
    packagesMissing="TRUE"
  fi
  libFile=/usr/lib/libXdmcp.so.6
  checkLibFileExists ${libFile}
  if [ "FALSE" == $rhLibFileExists ]; then
    packagesMissing="TRUE"
  fi
  
  # -- (RH6 and RH7) check 32 bit libXtst.i686 package for DM 
  ## =======================================================
  package=libXtst.i686
  checkRHPackageInstalled ${package}
  if [ "FALSE" == $rhPackageInstalled ]; then
    packagesMissing="TRUE"
  fi
  
  # -- (RH6 and RH7) check 32 bit libcanberra-gtk2.i686 package for DM 
  ## =======================================================
  package=libcanberra-gtk2.i686
  checkRHPackageInstalled ${package}
  if [ "FALSE" == $rhPackageInstalled ]; then 
    packagesMissing="TRUE"
  fi
  
  # -- (RH6 and RH7) check 32 bit libXmu.i686 package for DM 
  ## =======================================================
  package=libXmu.i686
  checkRHPackageInstalled ${package}
  if [ "FALSE" == $rhPackageInstalled ]; then 
    packagesMissing="TRUE"
  fi
  
  # -- (RH6 and RH7) check 32 bit gtk2.i686 package for DM 
  ## =======================================================
  package=gtk2.i686
  checkRHPackageInstalled ${package}
  if [ "FALSE" == $rhPackageInstalled ]; then 
    packagesMissing="TRUE"
  fi


  if [ "TRUE" == $bRH6flag ]; then
    echo "+++ check Red Hat 6 specific packages"
    
    # -- (RH6 only) check 32 bit PackageKit-gtk3-module.i686 package for DM (may not be needed for server)
    ## =======================================================
    package=PackageKit-gtk-module.i686
    checkRHPackageInstalled ${package}
    if [ "FALSE" == $rhPackageInstalled ]; then 
      packagesMissing="TRUE"
    fi
    
    # -- (RH6 only) check 32 bit libpng.i686 package for DM (may not be needed for server)
    # could also get libpng-devel.i686 if required
    # THIS PACKAGE IS NOT NEEDED ON RH6
    ## =======================================================
    ##package=libpng.i686
    
    # -- (RH6 only) check 32 bit gtk2-engines.i686 package for DM (may not be needed for server)
    ## =======================================================
    package=gtk2-engines.i686
    checkRHPackageInstalled ${package}
    if [ "FALSE" == $rhPackageInstalled ]; then 
      packagesMissing="TRUE"
    fi
    
  fi
  
  
  if [ "TRUE" == $bRH7flag ]; then
    echo "+++ check Red Hat 7 specific packages"
    
    # -- (RH7 only) check 32 bit PackageKit-gtk3-module.i686 package for DM (may not be needed for server)
    ## =======================================================
    package=PackageKit-gtk3-module.i686
    checkRHPackageInstalled ${package}
    if [ "FALSE" == $rhPackageInstalled ]; then 
      packagesMissing="TRUE"
    fi
    
    # -- (RH7 only) check 32 bit libpng12.i686 package for DM (may not be needed for server)
    ## =======================================================
    package=libpng12.i686
    checkRHPackageInstalled ${package}
    if [ "FALSE" == $rhPackageInstalled ]; then 
      packagesMissing="TRUE"
    fi
  fi

fi

if [ "TRUE" == $packagesMissing ]; then
  echo "ERROR: script "${scriptName}" at least one required preReq RH package is missing"
  exit 1
else
  echo "all required preReq RH package present"
fi

####################################
## EOF
echo "-- EOF [${scriptName}] SUCCESS --"
exit 0
