#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2016, 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Append DB2Parameter.properties when the topology uses a DB server.
'''

import os
import sys

# find qdlib from parent paths and add the first one to the Python search path
sys.path.append(next((p for p in ['..', '../..'] if os.path.exists(p + '/qdlib') and
                      (p + '/qdlib') not in sys.path), None))

from qdlib import qd, qd_props, resource


def main():
    '''
    Main function; see module documentation.
    '''
    db_vendor = qd_props.get_default_env_props().get_values('DB_VENDOR')
    supported_vendors = ['db2', 'oracle', 'sqlserver']

    if db_vendor in supported_vendors:
        qd.echo_info("Appending %sParameter.properties to env.properties..." % db_vendor)
        db_properties = resource.get_resource(
            'AutomationPrep/DatabaseParameters/%sParameter.properties' % db_vendor)
        qd_props.append_to_env_prop(db_properties)
    else:
        qd.echo_info("Skipped to append (db2)(oracle)(sql)Parameter.properties to env.properties"
                     " as DB is [%s]" % db_vendor)


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main()
    exit(0)
