#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2016, 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Reset the environment state to the initial:

1. Clean the UCD environment of all properties that may confuse things if the environment
   is reused, e.g., {globalTagList}
2. Delete the env.properties file
3. Create an empty env.properties file

Environment variables:

- AH_WEB_URL - UCD server
- AUTH_TOKEN - UCD server authorization token

Usage::

    clean_and_init_env.py APPLICATION_ID ENVIRONMENT_ID AGENT_ID
'''
import os
import sys

# find qdlib from parent paths and add the first one to the Python search path
sys.path.append(next((p for p in ['..', '../..'] if os.path.exists(p + '/qdlib') and
                      (p + '/qdlib') not in sys.path), None))

from AutomationPrep.Tagging import tags_lib
from qdlib import qd, ucd_client, qd_props


def main(argv):
    '''Main function; see module documentation.'''

    qd.echo_info("====== process inputs =========")
    arg_parsed = qd.process_inputs(argv, 'APPLICATION_ID,ENVIRONMENT_ID,AGENT_ID')

    # pylint error unbalanced-tuple-unpacking on this line because no guarantee that arg_parsed,
    # i.e., qd.process_inputs() always returns 3 items.  Probably should refactor.  For now, ignore.
    # pylint: disable=unbalanced-tuple-unpacking
    application_id, environment_id, agent_id = arg_parsed

    qd.echo_info("====== determine operating system =========")
    qd.echo_info('running on [%s] operating system' % qd.os_switch('linux', 'windows'))

    qd.echo_info("====== get environment properties =========")
    qd.echo_debug('LOCALSERVERPROPERTYFILE [%s]' % qd_props.DEFAULT_ENV_PROPS_LOCATION)

    # get UCD info from env variables
    client = ucd_client.UDClient.create_from_env2('AH_WEB_URL', 'AUTH_TOKEN')
    qd.echo_info("====== check the UCD agent <--> server connection =========")
    tags_lib.test_ucd_agent_connection(client, agent_id, fail_on_error=False)
    qd.echo_info("====== clearingUCDEnvironmentProperty using the ucd_client api ======")
    tags_lib.update_ucd_tag_listing(None, client, application_id, environment_id,
                                    update_callback=lambda topo: topo.clean())

    qd.echo_info("====== delete local server property file ======")
    qd.delete_file_if_exists(qd_props.DEFAULT_ENV_PROPS_LOCATION)

    qd.echo_info("====== create local server property file ======")
    qd.create_file(qd_props.DEFAULT_ENV_PROPS_LOCATION)

    # set QD_VERSION identification string
    env_props = qd_props.get_default_env_props()
    env_props.set_value(qd_props.UCD_PN_QD_VERSION, qd_props.QD_VERSION)


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main(sys.argv)
    exit(0)
