#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Update httpd.conf file.  See :func:`main` function.
'''
import os
import sys

# find qdlib from parent paths and add the first one to the Python search path
sys.path.append(next((p for p in ['..', '../..', '../../..'] if os.path.exists(p + '/qdlib') and
                      (p + '/qdlib') not in sys.path), None))

from qdlib import qd, qd_props


def main():
    '''
    Update httpd.conf file for proxy server.
    '''
    env_props = qd_props.get_default_env_props()

    http_root = qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                             qd_props.DEFAULT_REL_IHS_HOME)
    httpd_conf_file = qd.path_join(http_root, 'conf', 'httpd.conf')
    plugin_root = qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                               qd_props.DEFAULT_REL_PLUGINS_HOME)
    # Back up httpd.conf file
    qd.duplicate_file(httpd_conf_file, 'httpd_backup.conf')
    replacement_list = [('WebSpherePluginConfig', '#WebSpherePluginConfig')]
    # pylint: disable=line-too-long
    add_lines = [qd.escape_path(''.join(['LoadModule was_ap22_module ',
                                         qd.path_join(plugin_root, 'bin', qd.os_switch('64bits', '32bits'),
                                                      qd.os_switch('mod_was_ap22_http.so', 'mod_was_ap22_http.dll'))]))]
    add_lines += [qd.escape_path(''.join(['WebSpherePluginConfig ',
                                          qd.path_join(plugin_root, 'config', 'webservermerge', 'plugin-cfg.xml')]))]
    add_lines += ['LoadModule ibm_ssl_module modules/mod_ibm_ssl.so']
    add_lines += ['Listen 9443']
    add_lines += ['<VirtualHost *:9443>']
    add_lines += ['SSLEnable']
    add_lines += ['SSLServerCert ihsserver']
    add_lines += [' ']
    add_lines += ['</VirtualHost> ']
    add_lines += [' ']
    add_lines += [''.join(['KeyFile ', qd.path_join(http_root, 'ihsserverkey.kdb ')])]
    add_lines += [qd.escape_path(''.join(['SSLStashFile ', qd.path_join(http_root, 'ihsserverkey.sth')]))]
    add_lines += ['SSLDisable']
    add_lines += ['SetEnv websphere-nocanon 1']
    # pylint: enable=line-too-long
    qd.sed_in_place(httpd_conf_file, replacement_list)
    qd.append_content_to_file(httpd_conf_file, add_lines)


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main()
    exit(0)
