#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Create a WebServer in WebSphere application server.  See :func:`main` function.
'''
import os
import sys

# find qdlib from parent paths and add the first one to the Python search path
sys.path.append(next((p for p in ['..', '../..', '../../..'] if os.path.exists(p + '/qdlib') and
                      (p + '/qdlib') not in sys.path), None))

from qdlib import qd, qd_props, install_util, resource


def main(argv):
    '''
    Create a webserver in WebSphere

    :param argv: multiple arguments passed in: <ihshost> <webserver_name>
    '''
    expected_args = 2
    if len(argv) == expected_args:
        ihs_host = argv[0]
        webserver_name = argv[1]
    else:
        qd.echo_error("The number of argument suppose to be %s, but passed in [%s]"
                      % (expected_args, len(argv)))
        qd.echo_error("Expected to pass in <ihs hostname> <webserver name>")
        qd.exit_(1)

    env_props = qd_props.get_default_env_props()
    user_props = qd_props.get_user_props(env_props)
    os_user_name, os_user_password = qd_props.get_os_users_creds(user_props)

    _, was_admin_password = qd_props.get_was_admin_users(user_props)

    ldap_file = resource.get_resource(qd_props.DEFAULT_LDAP_REL_PATH)
    qd.duplicate_file(ldap_file, 'ldap_back.properties')
    # Update plain password in the temporary property file
    qd.sed_in_place(ldap_file, [(user_props.get_values(qd_props.PN_USER_WAS_USER_PASSWORD),
                                 was_admin_password)])

    http_dir = qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                            qd_props.DEFAULT_REL_IHS_HOME)
    plugins_dir = qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                               qd_props.DEFAULT_REL_PLUGINS_HOME)
    cmd = [qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                        qd_props.DEFAULT_REL_WAS_ROOT, 'bin',
                        qd_props.DEFAULT_WSADMIN_EXE),
           '-lang', 'jython', '-f', resource.get_resource('ConfigureWAS/create_webserver.jy'),
           qd.escape_path(ldap_file), ihs_host, webserver_name, qd.escape_path(http_dir),
           qd.escape_path(plugins_dir)]
    install_util.su_call_if_necessary('--', (os_user_name, os_user_password),
                                      cmd, call_method=qd.check_call)
    # Move original ldap file with encrypted password back
    qd.move_file(qd.path_join(qd.dirname(ldap_file), 'ldap_back.properties'), ldap_file)


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    if qd_props.check_app_server():
        main(sys.argv[1:])
    exit(0)
