#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Extract the certificate from WebSphere application server node.
'''
import os
import sys
import getpass

# find qdlib from parent paths and add the first one to the Python search path
sys.path.append(next((p for p in ['..', '../..', '../../..'] if os.path.exists(p + '/qdlib') and
                      (p + '/qdlib') not in sys.path), None))

from qdlib import qd, qd_props, install_util, qd_topo, resource


def main():
    '''
    Main function to extract certificate from WebSphere application server node.
    '''
    env_props = qd_props.get_default_env_props()
    user_props = qd_props.get_user_props(env_props)
    os_user_name, os_user_password = qd_props.get_os_users_creds(user_props)
    current_user = getpass.getuser()
    # set the folder for holding the certificate file
    cert_folder = qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                               qd_props.DEFAULT_REL_TMP_DIR)
    qd.check_and_create_folder(cert_folder)
    if qd.is_windows():
        cmd = ['net', 'share', ''.join([qd_props.DEFAULT_REL_TMP_DIR, '=', cert_folder]),
               ''.join(['/grant:', os_user_name, ',Read']),
               ''.join(['/grant:', current_user, ',Read'])]
        qd.check_call(cmd)
    # change the folder to be writable by other since the folder is created by root,
    # and accessed by os user
    qd.chmod_777(cert_folder, 'o+w')
    cert_file_path = qd.path_join(cert_folder, 'serverroot.cer')

    all_tag_listing = env_props.get_values(qd_props.UCD_PN_GLOBAL_TAG_LISTING)
    topo = qd_topo.QDTopo(all_tag_listing)
    local_host = env_props.get_values('localHostname', localHostname=qd.get_host_name())
    local_server_role = topo.get_host(local_host).get_local_server_role()

    if local_server_role == 'was':
        cmd = [qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                            qd_props.DEFAULT_REL_WAS_ROOT, 'bin',
                            qd_props.DEFAULT_WSADMIN_EXE),
               '-lang', 'jython', '-f',
               resource.get_resource('ConfigureWAS/extract_server1_cert.jy'),
               qd.escape_path(cert_file_path)]

    elif local_server_role == 'liberty':
        jts_dir = qd.path_join(env_props.get_values(qd_props.PN_CLM_HOME_PREP), 'server')
        key_dir = qd.path_join(jts_dir,
                               'liberty/servers/clm/resources/security')
        ikeycmd = qd.os_switch('jre/bin/ikeycmd', 'jre/bin/ikeycmd.exe')
        cmd = [qd.path_join(jts_dir, ikeycmd), '-cert', '-extract',
               '-db', qd.path_join(key_dir, 'ibm-team-ssl.keystore'), '-type', 'jks', '-pw',
               'ibm-team', '-label', 'default', '-target', qd.escape_path(cert_file_path)]

    install_util.su_call_if_necessary('--', (os_user_name, os_user_password),
                                      cmd, call_method=qd.check_call)


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    if qd_props.check_app_server():
        main()
    exit(0)
