#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
    Run create_database.py as the oracle user
'''
import sys
import os

# find qdlib from parent paths and add the first one to the Python search path
sys.path.append(next((p for p in ['..', '../..'] if os.path.exists(p + '/qdlib') and
                      (p + '/qdlib') not in sys.path), None))

from qdlib import qd, qd_props, install_util, resource


def main():
    '''
    Parent the python file that will launch another python script as a user defined
    '''
    # set up local environment for this script
    working_dir = os.getcwdu()
    env_props = qd_props.get_default_env_props()
    user_props = qd_props.get_user_props(env_props)  # get credentials
    oracle_user = user_props.get_values(qd_props.PN_ORACLE_OS_USER)
    oracle_user_password = qd.decode_base64(user_props.get_values(qd_props.PN_ORACLE_OS_PWD))

    # temporary turn on read mode for userCreds.properties
    # because it will be read by other OS users
    user_props_path = resource.get_resource(qd_props.DEFAULT_USER_CREDS_REL_PATH)
    qd.chmod_777(user_props_path, 'o+r')
    cmd = ['cd', working_dir, qd.os_switch(';', '&'), 'python', 'create_database.py']
    install_util.su_call_if_necessary('-', (oracle_user, oracle_user_password),
                                      cmd, call_method=qd.check_call)
    qd.chmod_777(user_props_path, 'o-r')


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main()
    exit(0)
